@@ -5,6 +5,7 @@ from typing import Tuple
 from tokenize_rt import Offset
 
 from pyupgrade._ast_helpers import ast_to_offset
+from pyupgrade._ast_helpers import is_async_listcomp
 from pyupgrade._data import register
 from pyupgrade._data import State
 from pyupgrade._data import TokenFunc
@@ -19,6 +20,7 @@ def visit_Starred(
 ) -> Iterable[Tuple[Offset, TokenFunc]]:
     if (
         state.settings.min_version >= (3,) and
-        isinstance(node.value, ast.ListComp)
+        isinstance(node.value, ast.ListComp) and
+        not is_async_listcomp(node.value)
     ):
         yield ast_to_offset(node.value), replace_list_comp_brackets
